magneticalc.Wire_Menu.Wire_Menu

# ``magneticalc`.`Wire_Menu`.`Wire_Menu``

class documentation

`class Wire_Menu(QMenu):`

Constructor: `Wire_Menu(gui)`

View In Hierarchy

Wire_Menu class.

Method | `__init__` | Initializes the menu.
Method | `update` | Updates the menu.
Method | `wire_export` | Exports wire points to a TXT file.
Method | `wire_import` | Imports wire points from a TXT file.
Instance Variable | `export_wire_action` | Undocumented
Instance Variable | `gui` | Undocumented
Instance Variable | `import_wire_action` | Undocumented

def __init__(self, gui: `GUI`):

Initializes the menu.

def update(self):

Updates the menu.

def wire_export(self):

Exports wire points to a TXT file.

def wire_import(self):

Imports wire points from a TXT file.

export_wire_action =

Undocumented

gui =

Undocumented

import_wire_action =

Undocumented